This is a complete directed dyad-year data frame of Correlates of War
state system members. I offer it here as a shortcut for various other functions when
I am working on new additions and don't want to invest time in waiting for
create_dyadyears() to run.
cow_ddyA data frame with 2063670 observations on the following 3 variables.
ccode1a numeric vector for the Correlates of War state code for the first state
ccode2a numeric vector for the Correlates of War state code for the second state
yeara numeric vector for the year
Data are a quick generation from the create_dyadyears() function in this package.