This is a complete (I believe) data set on Correlates of War states and Gleditsch-Ward states, a byproduct
of a full_join() between gw_states and cow_states that leans largely on the
state abbreviation variable
cow_gw_yearsA data frame with 18656 observations on the following 8 variables.
stateabbthe state abbreviation, which was the greatest source of agreement between both data sets
yeara numeric vector for the year
gwcodea Gleditsch-Ward state code
ccodea Correlates of War state code
gw_statenamethe state name as it appears in the Gleditsch-Ward data
cow_statenamethe state name as it appears in the Correlates of War data
The data-raw directory on the project's Github contains more information about how these data were
created. I'm going to use it for internal stuff. The workflow is going to treat the Correlates of War state system
membership codes as more of the "master" codes, for which the user can add Gleditsch-Ward identifiers as they see
fit.