This is a complete directed dyad-year data frame of Gleditsch-Ward state system members. I offer it here as a shortcut for various other functions.
gw_ddyA data frame with 1999558 observations on the following 4 variables.
gwcode1a numeric vector for the Correlates of War state code for the first state
gwcode2a numeric vector for the Correlates of War state code for the second state
yeara numeric vector for the year
Data are a quick generation from the create_dyadyears(system="gw") function in this package.