These are leader-level data drawn from the Archigos data. Space considerations mean I offer here just a few columns based on these data.
archigosA data frame with 3409 observations on the following seven variables.
ccodea numeric vector for the Correlates of War state code
leadidthe unique leader identifier
startdatea date for the leader start date
enddatea date for the leader end date
entrya character vector for the leader's entry type
exita character vector for the leader's exit type
exitcodea character vector for more information about the leader's exit type
Space considerations mean I can only offer a few columns from the overall data. Archigos data are rich with information. Consult the raw data available on Hein Goeman's website for more. Data are version 4.1.
Goemans, Henk E., Kristian Skrede Gleditsch, and Giacomo Chiozza. 2009. "Introducing Archigos: A Dataset of Political Leaders" Journal of Peace Research 46(2): 269--83.