This is a complete directed dyad-year data frame of Correlates of War state system members. I offer it here as a shortcut for various other functions.
cow_ddyA data frame with 2025840 observations on the following 4 variables.
ccode1a numeric vector for the Correlates of War state code for the first state
ccode2a numeric vector for the Correlates of War state code for the second state
yeara numeric vector for the year
Data are a quick generation from the create_dyadyears() function in this package.