These are the independent states in Gleditsch and Ward's data.
gw_statesA data frame with 216 observations on the following 5 variables.
gwcodea numeric vector for the Gleditsch-Ward country code
stateabba character vector for state abbreviation
statenamea character vector for the state name
startdatethe start date in the data
enddatethe end date in the data
Data originally provided by Gleditsch with no column names. Column names were added before some light re-cleaning in order to generate these data.
Gleditsch, Kristian S. and Michael D. Ward. 1999. "A Revised List of Independent States since the Congress of Vienna" 25(4): 393--413.